@@ -1037,6 +1037,7 @@ class DataflowWorkloadItem(OpenApiObject):
         'compute': {'type': 'DataflowComputeWorkload'},
         'all_reduce': {'type': 'DataflowAllReduceWorkload'},
         'broadcast': {'type': 'DataflowBroadcastWorkload'},
+        'all_to_all': {'type': 'DataflowAlltoallWorkload'},
     } # type: Dict[str, str]
 
     _REQUIRED = ('name', 'choice') # type: tuple(str)
@@ -1167,6 +1168,17 @@ class DataflowWorkloadItem(OpenApiObject):
         """
         self._set_property('choice', value)
 
+    @property
+    def all_to_all(self):
+        # type: () -> DataflowAlltoallWorkload
+        """all_to_all getter
+
+        creates full-mesh flows between all nodescreates full-mesh flows between all nodes
+
+        Returns: DataflowAlltoallWorkload
+        """
+        return self._get_property('all_to_all', DataflowAlltoallWorkload)
+
 
 class DataflowScatterWorkload(OpenApiObject):
     __slots__ = ('_parent')
@@ -1763,6 +1775,70 @@ class DataflowBroadcastWorkload(OpenApiObject):
         self._set_property('flow_profile_name', value)
 
 
+class DataflowAlltoallWorkload(OpenApiObject):
+    __slots__ = ('_parent')
+
+    _TYPES = {
+        'nodes': {
+            'type': list,
+            'itemtype': str,
+        },
+        'flow_profile_name': {'type': str},
+    } # type: Dict[str, str]
+
+    _REQUIRED= () # type: tuple(str)
+
+    _DEFAULTS= {} # type: Dict[str, Union(type)]
+
+    def __init__(self, parent=None, nodes=None, flow_profile_name=None):
+        super(DataflowAlltoallWorkload, self).__init__()
+        self._parent = parent
+        self._set_property('nodes', nodes)
+        self._set_property('flow_profile_name', flow_profile_name)
+
+    @property
+    def nodes(self):
+        # type: () -> List[str]
+        """nodes getter
+
+        TBD
+
+        Returns: List[str]
+        """
+        return self._get_property('nodes')
+
+    @nodes.setter
+    def nodes(self, value):
+        """nodes setter
+
+        TBD
+
+        value: List[str]
+        """
+        self._set_property('nodes', value)
+
+    @property
+    def flow_profile_name(self):
+        # type: () -> str
+        """flow_profile_name getter
+
+        flow profile reference
+
+        Returns: str
+        """
+        return self._get_property('flow_profile_name')
+
+    @flow_profile_name.setter
+    def flow_profile_name(self, value):
+        """flow_profile_name setter
+
+        flow profile reference
+
+        value: str
+        """
+        self._set_property('flow_profile_name', value)
+
+
 class DataflowFlowProfile(OpenApiObject):
     __slots__ = ('_parent')
 
@@ -2386,41 +2462,162 @@ class ErrorDetails(OpenApiObject):
     __slots__ = ('_parent')
 
     _TYPES = {
-        'errors': {
-            'type': list,
-            'itemtype': str,
-        },
+        'errors': {'type': 'ErrorItemIter'},
     } # type: Dict[str, str]
 
     _REQUIRED= () # type: tuple(str)
 
     _DEFAULTS= {} # type: Dict[str, Union(type)]
 
-    def __init__(self, parent=None, errors=None):
+    def __init__(self, parent=None):
         super(ErrorDetails, self).__init__()
         self._parent = parent
-        self._set_property('errors', errors)
 
     @property
     def errors(self):
-        # type: () -> List[str]
+        # type: () -> ErrorItemIter
         """errors getter
 
         TBD
 
-        Returns: List[str]
+        Returns: ErrorItemIter
         """
-        return self._get_property('errors')
+        return self._get_property('errors', ErrorItemIter, self._parent, self._choice)
 
-    @errors.setter
-    def errors(self, value):
-        """errors setter
+
+class ErrorItem(OpenApiObject):
+    __slots__ = ('_parent')
+
+    _TYPES = {
+        'message': {'type': str},
+        'code': {'type': int},
+        'detail': {'type': str},
+    } # type: Dict[str, str]
+
+    _REQUIRED= () # type: tuple(str)
+
+    _DEFAULTS= {} # type: Dict[str, Union(type)]
+
+    def __init__(self, parent=None, message=None, code=None, detail=None):
+        super(ErrorItem, self).__init__()
+        self._parent = parent
+        self._set_property('message', message)
+        self._set_property('code', code)
+        self._set_property('detail', detail)
+
+    @property
+    def message(self):
+        # type: () -> str
+        """message getter
 
         TBD
 
-        value: List[str]
+        Returns: str
         """
-        self._set_property('errors', value)
+        return self._get_property('message')
+
+    @message.setter
+    def message(self, value):
+        """message setter
+
+        TBD
+
+        value: str
+        """
+        self._set_property('message', value)
+
+    @property
+    def code(self):
+        # type: () -> int
+        """code getter
+
+        TBD
+
+        Returns: int
+        """
+        return self._get_property('code')
+
+    @code.setter
+    def code(self, value):
+        """code setter
+
+        TBD
+
+        value: int
+        """
+        self._set_property('code', value)
+
+    @property
+    def detail(self):
+        # type: () -> str
+        """detail getter
+
+        TBD
+
+        Returns: str
+        """
+        return self._get_property('detail')
+
+    @detail.setter
+    def detail(self, value):
+        """detail setter
+
+        TBD
+
+        value: str
+        """
+        self._set_property('detail', value)
+
+
+class ErrorItemIter(OpenApiIter):
+    __slots__ = ('_parent', '_choice')
+
+    _GETITEM_RETURNS_CHOICE_OBJECT = False
+
+    def __init__(self, parent=None, choice=None):
+        super(ErrorItemIter, self).__init__()
+        self._parent = parent
+        self._choice = choice
+
+    def __getitem__(self, key):
+        # type: (str) -> Union[ErrorItem]
+        return self._getitem(key)
+
+    def __iter__(self):
+        # type: () -> ErrorItemIter
+        return self._iter()
+
+    def __next__(self):
+        # type: () -> ErrorItem
+        return self._next()
+
+    def next(self):
+        # type: () -> ErrorItem
+        return self._next()
+
+    def item(self, message=None, code=None, detail=None):
+        # type: (str,int,str) -> ErrorItemIter
+        """Factory method that creates an instance of the ErrorItem class
+
+        TBD
+
+        Returns: ErrorItemIter
+        """
+        item = ErrorItem(parent=self._parent, message=message, code=code, detail=detail)
+        self._add(item)
+        return self
+
+    def add(self, message=None, code=None, detail=None):
+        # type: (str,int,str) -> ErrorItem
+        """Add method that creates and returns an instance of the ErrorItem class
+
+        TBD
+
+        Returns: ErrorItem
+        """
+        item = ErrorItem(parent=self._parent, message=message, code=code, detail=detail)
+        self._add(item)
+        return item
 
 
 class MetricsRequest(OpenApiObject):
